export { default } from "./cssContainerQueries.js";
export { isCqShorthand, getContainerQuery, sortContainerQueries } from "./cssContainerQueries.js";
export type { CssContainerQueries } from "./cssContainerQueries.js";